==> carbon-components-react-0.7.0.tgz: package/es/components/UIShell/HeaderContainer.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import PropTypes from 'prop-types';
import React, { useState, useCallback } from 'react';

var HeaderContainer = function HeaderContainer(_ref) {
  var isSideNavExpanded = _ref.isSideNavExpanded,
      Children = _ref.render,
      activeGlobalAction = _ref.activeGlobalAction;

  //state for expandable sidenav
  var _useState = useState(isSideNavExpanded),
      _useState2 = _slicedToArray(_useState, 2),
      isSideNavExpandedState = _useState2[0],
      setIsSideNavExpandedState = _useState2[1];

  var _useState3 = useState(activeGlobalAction),
      _useState4 = _slicedToArray(_useState3, 2),
      activeGlobalActionState = _useState4[0],
      setActiveGlobalActionState = _useState4[1];

  var handleHeaderMenuButtonClick = useCallback(function () {
    setIsSideNavExpandedState(!isSideNavExpandedState);
  }, [isSideNavExpandedState, setIsSideNavExpandedState]);

  var handleChangeGlobalAction = function handleChangeGlobalAction(globalAction) {
    setActiveGlobalActionState(globalAction);
  };

  return /*#__PURE__*/React.createElement(Children, {
    isSideNavExpanded: isSideNavExpandedState,
    onClickSideNavExpand: handleHeaderMenuButtonClick,
    activeGlobalAction: activeGlobalActionState,
    changeGlobalActionTo: handleChangeGlobalAction
  });
};

HeaderContainer.propTypes = {
  /**
   * Optionally provide initial state for expandable sidenav
   */
  isSideNavExpanded: PropTypes.bool,

  /**
   * Optionally provide globalAction to be active initially
   */
  activeGlobalAction: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};
HeaderContainer.defaultProps = {
  isSideNavExpanded: false
};
export default HeaderContainer;

==> carbon-components-react-0.8.1.tgz: package/es/components/UIShell/HeaderContainer.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import PropTypes from 'prop-types';
import React, { useState, useCallback } from 'react';

var HeaderContainer = function HeaderContainer(_ref) {
  var isSideNavExpanded = _ref.isSideNavExpanded,
      Children = _ref.render,
      activeGlobalAction = _ref.activeGlobalAction;

  //state for expandable sidenav
  var _useState = useState(isSideNavExpanded),
      _useState2 = _slicedToArray(_useState, 2),
      isSideNavExpandedState = _useState2[0],
      setIsSideNavExpandedState = _useState2[1];

  var _useState3 = useState(activeGlobalAction),
      _useState4 = _slicedToArray(_useState3, 2),
      activeGlobalActionState = _useState4[0],
      setActiveGlobalActionState = _useState4[1];

  var handleHeaderMenuButtonClick = useCallback(function () {
    setIsSideNavExpandedState(function (prevIsSideNavExpanded) {
      return !prevIsSideNavExpanded;
    });
  }, [setIsSideNavExpandedState]);

  var handleChangeGlobalAction = function handleChangeGlobalAction(globalAction) {
    setActiveGlobalActionState(globalAction);
  };

  return /*#__PURE__*/React.createElement(Children, {
    isSideNavExpanded: isSideNavExpandedState,
    onClickSideNavExpand: handleHeaderMenuButtonClick,
    activeGlobalAction: activeGlobalActionState,
    changeGlobalActionTo: handleChangeGlobalAction
  });
};

HeaderContainer.propTypes = {
  /**
   * Optionally provide globalAction to be active initially
   */
  activeGlobalAction: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /**
   * Optionally provide initial state for expandable sidenav
   */
  isSideNavExpanded: PropTypes.bool
};
HeaderContainer.defaultProps = {
  isSideNavExpanded: false
};
export default HeaderContainer;
